onStart method
Callback from the app when this task is to be started.
Implementation
@override
void onStart() {
super.onStart();
// resume collecting sensor data in the background
backgroundTaskExecutor.resume();
}
Callback from the app when this task is to be started.
@override
void onStart() {
super.onStart();
// resume collecting sensor data in the background
backgroundTaskExecutor.resume();
}